--
-- 4.3.0 TO 4.3.2 --
--
-- > cat ethereal-upgrade_430_432.sql | pgql-U [DBUSER] -h [DBHOST] -p [DBPORT] [DBNAME]
--                                  OR
-- > cat ethereal-upgrade_430_432.sql pgql-U [DBUSER] [DBNAME]
--
-- This release will enable a new functionality dealing with short names
-- for realms.   As a result, once you run this upgrade file once you will
-- have to run the ./mgmt/commandline/short.pl script in order to enable
-- short names and then run again after removing the comments around the
-- line containing 'CREATE UNIQUE INDEX idxRealm_Short'
--
-- The above will enable proper operation and proper security checks to
-- prevents conflicts from arising.
--
-- Also be sure to run the 'upgrade_tags.sql' file in order to make sure
-- you have all of the required tags in order to continue.


CREATE TABLE PGSCHEMA.Watch (
  PuppetName           VARCHAR(30)   NOT NULL,
  PuppetPool           VARCHAR(30)   NOT NULL,
  RealmName            VARCHAR(30)   NOT NULL,
  PuppeteerLogin       VARCHAR(10)   NOT NULL,
  CONSTRAINT pkWatch                 PRIMARY KEY (PuppetName, PuppetPool, RealmName, PuppeteerLogin),
  CONSTRAINT fkWatchPuppet FOREIGN KEY (PuppetName, PuppetPool)
    REFERENCES PGSCHEMA.Puppet (PuppetName, PuppetPool)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkWatchPuppeteer FOREIGN KEY (PuppeteerLogin)
    REFERENCES PGSCHEMA.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT fkWatchRealm FOREIGN KEY (RealmName)
    REFERENCES PGSCHEMA.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE
) WITHOUT OIDS;


-- OpenID Support
ALTER TABLE PGSCHEMA.Puppeteer ADD PuppeteerOpenID      VARCHAR(255);

CREATE UNIQUE INDEX idxPuppeteer_OpenID ON PGSCHEMA.Puppeteer
(
  PuppeteerOpenID
);

CREATE TABLE PGSCHEMA.OpenID (
  OpenIDServer         VARCHAR(255)  NOT NULL,
  OpenIDType           VARCHAR(9)    NOT NULL DEFAULT 'HMAC-SHA1',
  OpenIDAssociate      VARCHAR(255)  NOT NULL, 
  OpenIDExpires        TIMESTAMP     NOT NULL,
  OpenIDMac            VARCHAR(255)  NOT NULL,
  OpenIDState          VARCHAR(5)    NOT NULL DEFAULT 'smart',
  CONSTRAINT pkOpenID                PRIMARY KEY (OpenIDServer, OpenIDType, OpenIDAssociate),
  CONSTRAINT enumOpenIDState         CHECK (OpenIDState IN ('dumb','smart'))
) WITHOUT OIDS;

CREATE OR REPLACE FUNCTION PGSCHEMA.addInterval(interval) RETURNS TIMESTAMP WITHOUT TIME ZONE AS'
  SELECT LOCALTIMESTAMP + $1
 ' LANGUAGE SQL IMMUTABLE STRICT;

--
--
-- NAME        : Puppeteer Trust
-- REFERENCES  : Puppeteer
--
-- DESCRIPTION : Part of the OpenID implementation to establish trust.

CREATE TABLE PGSCHEMA.PuppeteerTrust (
  PuppeteerLogin       VARCHAR(10)    NOT NULL,
  OpenIDRoot           VARCHAR(255)   NOT NULL,
  OpenIDExpires        TIMESTAMP,
  OpenIDTrust          VARCHAR(5)     NOT NULL DEFAULT 'trust',
  CONSTRAINT fkPuppeteerTrust         FOREIGN KEY (PuppeteerLogin)
    REFERENCES PGSCHEMA.Puppeteer (PuppeteerLogin)
      ON DELETE CASCADE
      ON UPDATE CASCADE,
  CONSTRAINT enumPuppeteerTrust       CHECK (OpenIDTrust IN ('trust','never'))
) WITHOUT OIDS;


-- UNIQUE INDEX
CREATE UNIQUE INDEX pkPuppeteerTrust ON PGSCHEMA.PuppeteerTrust
(
  PuppeteerLogin, OpenIDRoot, OpenIDExpires
);


-- ALTER TO REALMS
ALTER TABLE PGSCHEMA.Realm ADD RealmShort VARCHAR(30);

-- UNIQUE INDEX
--CREATE UNIQUE INDEX idxRealm_Short ON PGSCHEMA.Realm
--(
--  RealmShort
--);


-- Remove for proper server availablility
DELETE FROM PGSCHEMA.Tag WHERE TagType='bio' AND TagName='TmplBase';